/*
 * "Copyright (c) 2005 Stanford University. All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose, without fee, and without written
 * agreement is hereby granted, provided that the above copyright
 * notice, the following two paragraphs and the author appear in all
 * copies of this software.
 * 
 * IN NO EVENT SHALL STANFORD UNIVERSITY BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 * ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
 * IF STANFORD UNIVERSITY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * STANFORD UNIVERSITY SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND STANFORD UNIVERSITY
 * HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
 * ENHANCEMENTS, OR MODIFICATIONS."
 */

/**
 *
 * C++ implementation of the gain-based TOSSIM radio model.
 *
 * @author Philip Levis
 * @date   Dec 10 2005
 */

#include <radio.h>
#include <sim_gain.h>

Radio::Radio() {}
Radio::~Radio() {}

void Radio::add(int src, int dest, double gain) {
  sim_gain_add(src, dest, gain);
}

double Radio::gain(int src, int dest) {
  return sim_gain_value(src, dest);
}

bool Radio::connected(int src, int dest) {
  return sim_gain_connected(src, dest);
}

void Radio::remove(int src, int dest) {
  sim_gain_remove(src, dest);
}

void Radio::setNoise(int node, double mean, double range) {
  sim_gain_set_noise_floor(node, mean, range);
}


void Radio::setSensitivity(double sensitivity) {
  sim_gain_set_sensitivity(sensitivity);
}
